[![Python Version](https://img.shields.io/pypi/pyversions/imlib.svg)](https://pypi.org/project/imlib)
[![PyPI](https://img.shields.io/pypi/v/imlib.svg)](https://pypi.org/project/imlib)
[![Wheel](https://img.shields.io/pypi/wheel/imlib.svg)](https://pypi.org/project/imlib)
[![Development Status](https://img.shields.io/pypi/status/imlib.svg)](https://github.com/adamltyson/imlib)
[![Travis](https://img.shields.io/travis/com/adamltyson/imlib?label=Travis%20CI)](
    https://travis-ci.com/adamltyson/imlib)
[![Coverage Status](https://coveralls.io/repos/github/adamltyson/imlib/badge.svg?branch=master)](https://coveralls.io/github/adamltyson/imlib?branch=master)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/python/black)


# imlib
General image processing functions
